@@ -29,10 +29,10 @@ class CosmoInterp(object):
         self._cosmo = cosmo
         if float(astropy.__version__[0]) < 5.0:
             from lenstronomy.Cosmo._cosmo_interp_astropy_v4 import CosmoInterp as CosmoInterp_
-            self._comoving_interp = CosmoInterp_(cosmo, z_stop=z_stop, num_interp=num_interp)
+            self._comoving_interp = CosmoInterp_(cosmo)
         else:
             from lenstronomy.Cosmo._cosmo_interp_astropy_v5 import CosmoInterp as CosmoInterp_
-            self._comoving_interp = CosmoInterp_(cosmo, z_stop=z_stop, num_interp=num_interp)
+            self._comoving_interp = CosmoInterp_(cosmo)
         self._comoving_distance_interpolation_func = self._interpolate_comoving_distance(z_start=0, z_stop=z_stop,
                                                                                          num_interp=num_interp)
 
