@@ -1,15 +1,16 @@
 import numpy as np
 from lenstronomy.Data.coord_transforms import Coordinates
+from lenstronomy.Data.angular_sensitivity import AngularSensitivity
 
 __all__ = ['PixelGrid']
 
 
-class PixelGrid(Coordinates):
+class PixelGrid(Coordinates, AngularSensitivity):
     """
     class that manages a specified pixel grid (rectangular at the moment) and its coordinates
     """
 
-    def __init__(self, nx, ny, transform_pix2angle, ra_at_xy_0, dec_at_xy_0):
+    def __init__(self, nx, ny, transform_pix2angle, ra_at_xy_0, dec_at_xy_0, antenna_primary_beam=None):
         """
 
         :param nx: number of pixels in x-axis
@@ -17,11 +18,18 @@ class PixelGrid(Coordinates):
         :param transform_pix2angle: 2x2 matrix, mapping of pixel to coordinate
         :param ra_at_xy_0: ra coordinate at pixel (0,0)
         :param dec_at_xy_0: dec coordinate at pixel (0,0)
+        :param antenna_primary_beam: 2d numpy array with the same size of imaga_data;
+         more descriptions of the primary beam can be found in the AngularSensitivity class
         """
         super(PixelGrid, self).__init__(transform_pix2angle, ra_at_xy_0, dec_at_xy_0)
         self._nx = nx
         self._ny = ny
         self._x_grid, self._y_grid = self.coordinate_grid(nx, ny)
+        if antenna_primary_beam is not None:
+            pbx, pby = np.shape(antenna_primary_beam)
+            if (pbx, pby) != (nx, ny):
+                raise ValueError("The primary beam should have the same size with the image data!")
+        AngularSensitivity.__init__(self, antenna_primary_beam)
 
     @property
     def num_pixel(self):
@@ -72,4 +80,4 @@ class PixelGrid(Coordinates):
 
         :return: RA coords, DEC coords
         """
-        return self._x_grid, self._y_grid
+        return self._x_grid, self._y_grid
\ No newline at end of file
