@@ -111,10 +111,10 @@ def project2d_random(r):
         size = None
     u1 = np.random.uniform(0, 1, size=size)
     u2 = np.random.uniform(0, 1, size=size)
-    l = np.arccos(2*u1 - 1) - np.pi / 2
+    eta = np.arccos(2*u1 - 1) - np.pi / 2
     phi = 2 * np.pi * u2
-    x = r * np.cos(l) * np.cos(phi)
-    y = r * np.cos(l) * np.sin(phi)
+    x = r * np.cos(eta) * np.cos(phi)
+    y = r * np.cos(eta) * np.sin(phi)
     # z = r * np.sin(l)
     R = np.sqrt(x**2 + y**2)
     return R, x, y
