@@ -152,7 +152,7 @@ class PixelKernelConvolution(object):
         #    in1, s1, in2, s2 = in2, s2, in1, s1
 
         # Speed up FFT by padding to optimal size for FFTPACK
-        fshape = [fftpack.helper.next_fast_len(int(d)) for d in shape]
+        fshape = [fftpack.next_fast_len(int(d)) for d in shape]
         fslice = tuple([slice(0, int(sz)) for sz in shape])
         # Pre-1.9 NumPy FFT routines are not threadsafe.  For older NumPys, make
         # sure we only call rfftn/irfftn from one thread at a time.
@@ -191,7 +191,7 @@ class SubgridKernelConvolution(object):
         :param kernel_supersampled: kernel in supersampled pixels
         :param supersampling_factor: supersampling factor relative to the image pixel grid
         :param supersampling_kernel_size: number of pixels (in units of the image pixels) that are convolved with the
-        supersampled kernel
+         supersampled kernel
         """
         # n_high = len(kernel_supersampled)
         self._supersampling_factor = supersampling_factor
@@ -253,7 +253,7 @@ class MultiGaussianConvolution(object):
         :param fraction_list: fraction of flux to be convoled with each Gaussian kernel
         :param pixel_scale: scale of pixel width (to convert sigmas into units of pixels)
         :param truncation: float. Truncate the filter at this many standard deviations.
-        Default is 4.0.
+         Default is 4.0.
         """
         self._num_gaussians = len(sigma_list)
         self._sigmas_scaled = np.array(sigma_list) / pixel_scale
@@ -276,10 +276,10 @@ class MultiGaussianConvolution(object):
         image_conv = None
         for i in range(self._num_gaussians):
             if image_conv is None:
-                image_conv = ndimage.filters.gaussian_filter(image, self._sigmas_scaled[i], mode='nearest',
+                image_conv = ndimage.gaussian_filter(image, self._sigmas_scaled[i], mode='nearest',
                                                              truncate=self._truncation) * self._fraction_list[i]
             else:
-                image_conv += ndimage.filters.gaussian_filter(image, self._sigmas_scaled[i], mode='nearest',
+                image_conv += ndimage.gaussian_filter(image, self._sigmas_scaled[i], mode='nearest',
                                                               truncate=self._truncation) * self._fraction_list[i]
         return image_conv
 
