@@ -16,9 +16,10 @@ class Solver4Point(object):
     def __init__(self, lensModel, solver_type='PROFILE'):
         self._solver_type = solver_type  # supported:
         if not lensModel.lens_model_list[0] in ['SPEP', 'SPEMD', 'PEMD', 'SIE', 'NIE', 'NFW_ELLIPSE', 'NFW_ELLIPSE_CSE',
-                                                'SHAPELETS_CART', 'CNFW_ELLIPSE', 'EPL']:
+                                                'SHAPELETS_CART', 'CNFW_ELLIPSE', 'EPL', 'EPL_BOXYDISKY']:
             raise ValueError("first lens model must be supported by the solver: 'SPEP', 'SPEMD', 'PEMD',"
-                             " 'SIE', 'NIE', 'EPL', 'NFW_ELLIPSE', 'NFW_ELLIPSE_CSE', 'SHAPELETS_CART', 'CNFW_ELLIPSE'."
+                             " 'SIE', 'NIE', 'EPL', 'EPL_BOXYDISKY', 'NFW_ELLIPSE', 'NFW_ELLIPSE_CSE', "
+                             "'SHAPELETS_CART', 'CNFW_ELLIPSE'."
                              "Your choice was %s" % lensModel.lens_model_list[0])
         if solver_type not in ['PROFILE', 'PROFILE_SHEAR']:
             raise ValueError("solver_type %s not supported! Choose from 'PROFILE', 'PROFILE_SHEAR'"
@@ -126,13 +127,14 @@ class Solver4Point(object):
             kwargs_list[1]['gamma1'] = gamma1
             kwargs_list[1]['gamma2'] = gamma2
         lens_model = self._lens_mode_list[0]
-        if lens_model in ['SPEP', 'SPEMD', 'SIE', 'NIE', 'PEMD', 'EPL']:
+        if lens_model in ['SPEP', 'SPEMD', 'SIE', 'NIE', 'PEMD', 'EPL', 'EPL_BOXYDISKY']:
             [theta_E, e1, e2, center_x, center_y, _] = x
             kwargs_list[0]['theta_E'] = theta_E
             kwargs_list[0]['e1'] = e1
             kwargs_list[0]['e2'] = e2
             kwargs_list[0]['center_x'] = center_x
             kwargs_list[0]['center_y'] = center_y
+
         elif lens_model in ['NFW_ELLIPSE', 'CNFW_ELLIPSE', 'NFW_ELLIPSE_CSE']:
             [alpha_Rs, e1, e2, center_x, center_y, _] = x
             kwargs_list[0]['alpha_Rs'] = alpha_Rs
@@ -170,13 +172,14 @@ class Solver4Point(object):
         else:
             phi_ext = 0
         lens_model = self._lens_mode_list[0]
-        if lens_model in ['SPEP', 'SPEMD', 'SIE', 'NIE', 'PEMD', 'EPL']:
+        if lens_model in ['SPEP', 'SPEMD', 'SIE', 'NIE', 'PEMD', 'EPL', 'EPL_BOXYDISKY']:
             e1 = kwargs_list[0]['e1']
             e2 = kwargs_list[0]['e2']
             center_x = kwargs_list[0]['center_x']
             center_y = kwargs_list[0]['center_y']
             theta_E = kwargs_list[0]['theta_E']
             x = [theta_E, e1, e2, center_x, center_y, phi_ext]
+
         elif lens_model in ['NFW_ELLIPSE', 'CNFW_ELLIPSE', 'NFW_ELLIPSE_CSE']:
             e1 = kwargs_list[0]['e1']
             e2 = kwargs_list[0]['e2']
@@ -206,7 +209,7 @@ class Solver4Point(object):
         if self._solver_type in ['PROFILE_SHEAR', 'PROFILE_SHEAR_GAMMA_PSI']:
             pass
             # kwargs_fixed_lens_list[1]['psi_ext'] = kwargs_lens_init[1]['psi_ext']
-        if lens_model in ['SPEP', 'SPEMD', 'SIE', 'NIE', 'PEMD', 'EPL']:
+        if lens_model in ['SPEP', 'SPEMD', 'SIE', 'NIE', 'PEMD', 'EPL', 'EPL_BOXYDISKY']:
             kwargs_fixed['theta_E'] = kwargs_lens['theta_E']
             kwargs_fixed['e1'] = kwargs_lens['e1']
             kwargs_fixed['e2'] = kwargs_lens['e2']
