@@ -1,5 +1,6 @@
 __author__ = 'sibirrer'
 from lenstronomy.LensModel.single_plane import SinglePlane
+from lenstronomy.LensModel.LineOfSight.single_plane_los import SinglePlaneLOS
 from lenstronomy.LensModel.MultiPlane.multi_plane import MultiPlane
 from lenstronomy.Cosmo.lens_cosmo import LensCosmo
 from lenstronomy.Util import constants as const
@@ -14,34 +15,35 @@ class LensModel(object):
 
     def __init__(self, lens_model_list, z_lens=None, z_source=None, lens_redshift_list=None, cosmo=None,
                  multi_plane=False, numerical_alpha_class=None, observed_convention_index=None,
-                 z_source_convention=None, cosmo_interp=False, z_interp_stop=None, num_z_interp=100,
+                 z_source_convention=None, cosmo_interp=False,
+                 z_interp_stop=None, num_z_interp=100,
                  kwargs_interp=None):
         """
 
         :param lens_model_list: list of strings with lens model names
         :param z_lens: redshift of the deflector (only considered when operating in single plane mode).
-        Is only needed for specific functions that require a cosmology.
+         Is only needed for specific functions that require a cosmology.
         :param z_source: redshift of the source: Needed in multi_plane option only,
-        not required for the core functionalities in the single plane mode.
+         not required for the core functionalities in the single plane mode.
         :param lens_redshift_list: list of deflector redshift (corresponding to the lens model list),
-        only applicable in multi_plane mode.
+         only applicable in multi_plane mode.
         :param cosmo: instance of the astropy cosmology class. If not specified, uses the default cosmology.
         :param multi_plane: bool, if True, uses multi-plane mode. Default is False.
         :param numerical_alpha_class: an instance of a custom class for use in NumericalAlpha() lens model
-        (see documentation in Profiles/numerical_alpha)
+         (see documentation in Profiles/numerical_alpha)
         :param kwargs_interp: interpolation keyword arguments specifying the numerics.
          See description in the Interpolate() class. Only applicable for 'INTERPOL' and 'INTERPOL_SCALED' models.
         :param observed_convention_index: a list of indices, corresponding to the lens_model_list element with same
-        index, where the 'center_x' and 'center_y' kwargs correspond to observed (lensed) positions, not physical
-        positions. The code will compute the physical locations when performing computations
+         index, where the 'center_x' and 'center_y' kwargs correspond to observed (lensed) positions, not physical
+         positions. The code will compute the physical locations when performing computations
         :param z_source_convention: float, redshift of a source to define the reduced deflection angles of the lens
-        models. If None, 'z_source' is used.
+         models. If None, 'z_source' is used.
         :param cosmo_interp: boolean (only employed in multi-plane mode), interpolates astropy.cosmology distances for
-        faster calls when accessing several lensing planes
+         faster calls when accessing several lensing planes
         :param z_interp_stop: (only in multi-plane with cosmo_interp=True); maximum redshift for distance interpolation
-        This number should be higher or equal the maximum of the source redshift and/or the z_source_convention
+         This number should be higher or equal the maximum of the source redshift and/or the z_source_convention
         :param num_z_interp: (only in multi-plane with cosmo_interp=True); number of redshift bins for interpolating
-        distances
+         distances
         """
         self.lens_model_list = lens_model_list
         self.z_lens = z_lens
@@ -53,11 +55,26 @@ class LensModel(object):
             from astropy.cosmology import default_cosmology
             cosmo = default_cosmology.get()
         self.cosmo = cosmo
+
+        # Are there line-of-sight corrections?
+        permitted_los_models = ['LOS', 'LOS_MINIMAL']
+        los_models = [(i, model) for (i, model) in enumerate(lens_model_list)
+                      if model in permitted_los_models]
+        if len(los_models) == 0:
+            los_effects = False
+        elif len(los_models) == 1:
+            los_effects = True
+            index_los, los_model = los_models[0]
+        else:
+            raise ValueError('You can only have one model for line-of-sight corrections.')
+
+        # Multi-plane or single-plane lensing?
         self.multi_plane = multi_plane
         if multi_plane is True:
             if z_source is None:
                 raise ValueError('z_source needs to be set for multi-plane lens modelling.')
-
+            if los_effects is True:
+                raise ValueError('LOS effects and multi-plane lensing are incompatible.')
             self.lens_model = MultiPlane(z_source, lens_model_list, lens_redshift_list, cosmo=cosmo,
                                          numerical_alpha_class=numerical_alpha_class,
                                          observed_convention_index=observed_convention_index,
@@ -65,9 +82,20 @@ class LensModel(object):
                                          z_interp_stop=z_interp_stop, num_z_interp=num_z_interp,
                                          kwargs_interp=kwargs_interp)
         else:
-            self.lens_model = SinglePlane(lens_model_list, numerical_alpha_class=numerical_alpha_class,
-                                          lens_redshift_list=lens_redshift_list,
-                                          z_source_convention=z_source_convention, kwargs_interp=kwargs_interp)
+            if los_effects is True:
+                self.lens_model = SinglePlaneLOS(lens_model_list,
+                    index_los=index_los,
+                    numerical_alpha_class=numerical_alpha_class,
+                    lens_redshift_list=lens_redshift_list,
+                    z_source_convention=z_source_convention,
+                    kwargs_interp=kwargs_interp)
+            else:
+                self.lens_model = SinglePlane(lens_model_list,
+                    numerical_alpha_class=numerical_alpha_class,
+                    lens_redshift_list=lens_redshift_list,
+                    z_source_convention=z_source_convention,
+                    kwargs_interp=kwargs_interp)
+
         if z_lens is not None and z_source is not None:
             self._lensCosmo = LensCosmo(z_lens, z_source, cosmo=cosmo)
 
