@@ -2,10 +2,59 @@ import numpy as np
 
 __all__ = ['PointSourceParam']
 
+from lenstronomy.Sampling.param_group import ModelParamGroup, SingleParam, ArrayParam
+
+
+class SourcePositionParam(SingleParam):
+    """
+    Source position parameter, ra_source and dec_source
+    """
+    param_names = ['ra_source', 'dec_source']
+    _kwargs_lower = {'ra_source': -100, 'dec_source': -100}
+    _kwargs_upper = {'ra_source': 100, 'dec_source': 100}
+
+
+class LensedPosition(ArrayParam):
+    """
+    Represents lensed positions, possibly many. ra_image and dec_image
+
+    :param num_images: integer. The number of lensed positions to model.
+    """
+    _kwargs_lower = {'ra_image': -100, 'dec_image': -100, }
+    _kwargs_upper = {'ra_image': 100, 'dec_image': 100, }
+
+    def __init__(self, num_images):
+        ArrayParam.__init__(self, int(num_images) > 0)
+        self.param_names = {'ra_image': int(num_images), 'dec_image': int(num_images)}
+
+
+class SourceAmp(SingleParam):
+    """
+    Source amplification
+    """
+    param_names = ['source_amp']
+    _kwargs_lower = {'source_amp': 0}
+    _kwargs_upper = {'source_amp': 100}
+
+
+class ImageAmp(ArrayParam):
+    """
+    Observed amplification of lensed images of a point source. Can model
+    arbitrarily many magnified images
+
+    :param num_point_sources: integer. The number of lensed images without fixed magnification.
+    """
+    _kwargs_lower = {'point_amp': 0}
+    _kwargs_upper = {'point_amp': 100}
+
+    def __init__(self, num_point_sources):
+        ArrayParam.__init__(self, int(num_point_sources) > 0)
+        self.param_names = {'point_amp': int(num_point_sources)}
+
 
 class PointSourceParam(object):
     """
-
+    Point source parameters
     """
 
     def __init__(self, model_list, kwargs_fixed, num_point_source_list=None, linear_solver=True,
@@ -16,9 +65,9 @@ class PointSourceParam(object):
         :param kwargs_fixed: list of keyword arguments with parameters to be held fixed
         :param num_point_source_list: list of number of point sources per point source model class
         :param linear_solver: bool, if True, does not return linear parameters for the sampler
-        (will be solved linearly instead)
+         (will be solved linearly instead)
         :param fixed_magnification_list: list of booleans, if entry is True, keeps one overall scaling among the
-        point sources in this class
+         point sources in this class
         """
         self.model_list = model_list
         if num_point_source_list is None:
@@ -32,36 +81,40 @@ class PointSourceParam(object):
             self.kwargs_fixed = self.add_fix_linear(kwargs_fixed)
         self._linear_solver = linear_solver
 
+        self.param_groups = []
+        for i, model in enumerate(self.model_list):
+            params = []
+            num = num_point_source_list[i]
+            if model in ['LENSED_POSITION', 'UNLENSED']:
+                params.append(LensedPosition(num))
+            elif model == 'SOURCE_POSITION':
+                params.append(SourcePositionParam(True))
+            else:
+                raise ValueError("%s not a valid point source model" % model)
+
+            if fixed_magnification_list[i] and model in ['LENSED_POSITION', 'SOURCE_POSITION']:
+                params.append(SourceAmp(True))
+            else:
+                params.append(ImageAmp(num))
+
+            self.param_groups.append(params)
+
         if kwargs_lower is None:
             kwargs_lower = []
-            for k, model in enumerate(self.model_list):
-                num = self._num_point_sources_list[k]
-                if model in ['LENSED_POSITION', 'UNLENSED']:
-                    fixed_low = {'ra_image': [-100] * num, 'dec_image': [-100] * num}
-                elif model in ['SOURCE_POSITION']:
-                    fixed_low = {'ra_source': -100, 'dec_source': -100}
-                else:
-                    raise ValueError("%s not a valid point source model" % model)
-                if self._fixed_magnification_list[k] is True and model in ['LENSED_POSITION', 'SOURCE_POSITION']:
-                    fixed_low['source_amp'] = 0
-                else:
-                    fixed_low['point_amp'] = np.zeros(num)
-                kwargs_lower.append(fixed_low)
+            for model_params in self.param_groups:
+                fixed_lower = {}
+                for param_group in model_params:
+                    fixed_lower = dict(fixed_lower, **param_group.kwargs_lower)
+                kwargs_lower.append(fixed_lower)
+
         if kwargs_upper is None:
             kwargs_upper = []
-            for k, model in enumerate(self.model_list):
-                num = self._num_point_sources_list[k]
-                if model in ['LENSED_POSITION', 'UNLENSED']:
-                    fixed_high = {'ra_image': [100] * num, 'dec_image': [100] * num}
-                elif model in ['SOURCE_POSITION']:
-                    fixed_high = {'ra_source': 100, 'dec_source': 100}
-                else:
-                    raise ValueError("%s not a valid point source model" % model)
-                if self._fixed_magnification_list[k] is True and model in ['LENSED_POSITION', 'SOURCE_POSITION']:
-                    fixed_high['source_amp'] = 100
-                else:
-                    fixed_high['point_amp'] = np.ones(num)*100
-                kwargs_upper.append(fixed_high)
+            for model_params in self.param_groups:
+                fixed_upper = {}
+                for param_group in model_params:
+                    fixed_upper = dict(fixed_upper, **param_group.kwargs_upper)
+                kwargs_upper.append(fixed_upper)
+
         self.lower_limit = kwargs_lower
         self.upper_limit = kwargs_upper
 
@@ -73,45 +126,10 @@ class PointSourceParam(object):
         :return: keyword argument list of point sources, index relevant for the next class
         """
         kwargs_list = []
-        for k, model in enumerate(self.model_list):
-            kwargs = {}
-            kwargs_fixed = self.kwargs_fixed[k]
-            if model in ['LENSED_POSITION', 'UNLENSED']:
-                if 'ra_image' not in kwargs_fixed:
-                    kwargs['ra_image'] = np.array(args[i:i + self._num_point_sources_list[k]])
-                    i += self._num_point_sources_list[k]
-                else:
-                    kwargs['ra_image'] = kwargs_fixed['ra_image']
-                if 'dec_image' not in kwargs_fixed:
-                    kwargs['dec_image'] = np.array(args[i:i + self._num_point_sources_list[k]])
-                    i += self._num_point_sources_list[k]
-                else:
-                    kwargs['dec_image'] = kwargs_fixed['dec_image']
-            if model in ['SOURCE_POSITION']:
-                if 'ra_source' not in kwargs_fixed:
-                    kwargs['ra_source'] = args[i]
-                    i += 1
-                else:
-                    kwargs['ra_source'] = kwargs_fixed['ra_source']
-                if 'dec_source' not in kwargs_fixed:
-                    kwargs['dec_source'] = args[i]
-                    i += 1
-                else:
-                    kwargs['dec_source'] = kwargs_fixed['dec_source']
-            # amplitude parameter handling
-            if self._fixed_magnification_list[k] is True and model in ['LENSED_POSITION', 'SOURCE_POSITION']:
-                if 'source_amp' not in kwargs_fixed:
-                    kwargs['source_amp'] = args[i]
-                    i += 1
-                else:
-                    kwargs['source_amp'] = kwargs_fixed['source_amp']
-            else:
-                if 'point_amp' not in kwargs_fixed:
-                    kwargs['point_amp'] = np.array(args[i:i + self._num_point_sources_list[k]])
-                    i += self._num_point_sources_list[k]
-                else:
-                    kwargs['point_amp'] = kwargs_fixed['point_amp']
-
+        for k, param_group in enumerate(self.param_groups):
+            kwargs, i = ModelParamGroup.compose_get_params(
+                param_group, args, i, kwargs_fixed=self.kwargs_fixed[k]
+            )
             kwargs_list.append(kwargs)
         return kwargs_list, i
 
@@ -122,32 +140,12 @@ class PointSourceParam(object):
         :return: sorted list of parameters being sampled extracted from kwargs_list
         """
         args = []
-        for k, model in enumerate(self.model_list):
+        for k, param_group in enumerate(self.param_groups):
             kwargs = kwargs_list[k]
             kwargs_fixed = self.kwargs_fixed[k]
-            if model in ['LENSED_POSITION', 'UNLENSED']:
-                if 'ra_image' not in kwargs_fixed:
-                    x_pos = kwargs['ra_image'][0:self._num_point_sources_list[k]]
-                    for x in x_pos:
-                        args.append(x)
-                if 'dec_image' not in kwargs_fixed:
-                    y_pos = kwargs['dec_image'][0:self._num_point_sources_list[k]]
-                    for y in y_pos:
-                        args.append(y)
-            if model in ['SOURCE_POSITION']:
-                if 'ra_source' not in kwargs_fixed:
-                    args.append(kwargs['ra_source'])
-                if 'dec_source' not in kwargs_fixed:
-                    args.append(kwargs['dec_source'])
-            # amplitude parameter handling
-            if self._fixed_magnification_list[k] is True and model in ['LENSED_POSITION', 'SOURCE_POSITION']:
-                if 'source_amp' not in kwargs_fixed:
-                    args.append(kwargs['source_amp'])
-            else:
-                if 'point_amp' not in kwargs_fixed:
-                    amp = kwargs['point_amp'][0:self._num_point_sources_list[k]]
-                    for a in amp:
-                        args.append(a)
+            args.extend(ModelParamGroup.compose_set_params(
+                param_group, kwargs, kwargs_fixed=kwargs_fixed
+            ))
         return args
 
     def num_param(self):
@@ -156,36 +154,13 @@ class PointSourceParam(object):
 
         :return: int, list of parameter names
         """
-        num = 0
-        name_list = []
-        for k, model in enumerate(self.model_list):
-            kwargs_fixed = self.kwargs_fixed[k]
-            if model in ['LENSED_POSITION', 'UNLENSED']:
-                if 'ra_image' not in kwargs_fixed:
-                    num += self._num_point_sources_list[k]
-                    for i in range(self._num_point_sources_list[k]):
-                        name_list.append('ra_image')
-                if 'dec_image' not in kwargs_fixed:
-                    num += self._num_point_sources_list[k]
-                    for i in range(self._num_point_sources_list[k]):
-                        name_list.append('dec_image')
-            if model in ['SOURCE_POSITION']:
-                if 'ra_source' not in kwargs_fixed:
-                    num += 1
-                    name_list.append('ra_source')
-                if 'dec_source' not in kwargs_fixed:
-                    num += 1
-                    name_list.append('dec_source')
-            # amplitude handling
-            if self._fixed_magnification_list[k] is True and model in ['LENSED_POSITION', 'SOURCE_POSITION']:
-                if 'source_amp' not in kwargs_fixed:
-                    num += 1
-                    name_list.append('source_amp')
-            else:
-                if 'point_amp' not in kwargs_fixed:
-                    num += self._num_point_sources_list[k]
-                    for i in range(self._num_point_sources_list[k]):
-                        name_list.append('point_amp')
+        num, name_list = 0, []
+        for k, param_group in enumerate(self.param_groups):
+            n, names = ModelParamGroup.compose_num_params(
+                param_group, kwargs_fixed=self.kwargs_fixed[k]
+            )
+            num += n
+            name_list += names
         return num, name_list
 
     def add_fix_linear(self, kwargs_fixed):
