@@ -9,7 +9,7 @@ import lenstronomy.Util.util as util
 
 
 class TestData(object):
-    def setup(self):
+    def setup_method(self):
         self.numPix = 10
         kwargs_data = {'image_data': np.zeros((self.numPix, self.numPix)), 'noise_map': np.ones((self.numPix, self.numPix))}
         self.Data = ImageData(**kwargs_data)
