@@ -13,7 +13,7 @@ class TestChameleon(object):
     """
     class to test the Moffat profile
     """
-    def setup(self):
+    def setup_method(self):
         self.chameleon = Chameleon()
         self.nie = NIE()
 
@@ -103,7 +103,7 @@ class TestDoubleChameleon(object):
     """
     class to test the Moffat profile
     """
-    def setup(self):
+    def setup_method(self):
         pass
 
     def test_param_name(self):
@@ -209,7 +209,7 @@ class TestDoubleChameleonPointMass(object):
     """
     class to test the Moffat profile
     """
-    def setup(self):
+    def setup_method(self):
         pass
 
     def test_param_name(self):
@@ -267,7 +267,7 @@ class TestTripleChameleon(object):
     """
     class to test the Moffat profile
     """
-    def setup(self):
+    def setup_method(self):
         pass
 
     def test_param_name(self):
