@@ -12,7 +12,7 @@ class Testcnfw(object):
     """
     tests the Gaussian methods
     """
-    def setup(self):
+    def setup_method(self):
 
         self.cn = CNFW()
         self.n = NFW()
