@@ -12,7 +12,7 @@ class TestcBurk(object):
     """
     tests the Gaussian methods
     """
-    def setup(self):
+    def setup_method(self):
 
         self.cb = CoreBurkert()
 
