@@ -11,7 +11,7 @@ class TestP_JAFFW(object):
     """
     tests the Gaussian methods
     """
-    def setup(self):
+    def setup_method(self):
         self.profile = PJaffe()
 
     def test_function(self):
