@@ -12,7 +12,7 @@ class TestSIS(object):
     """
     tests the Gaussian methods
     """
-    def setup(self):
+    def setup_method(self):
         self.pointmass = PointMass()
 
     def test_function(self):
