@@ -11,7 +11,7 @@ class TestCartShapelets(object):
     """
     tests the Gaussian methods
     """
-    def setup(self):
+    def setup_method(self):
         self.polarShapelets = PolarShapelets()
 
     def test_function(self):
