@@ -18,7 +18,7 @@ class TestSPEMD(object):
     """
     tests the Gaussian methods
     """
-    def setup(self):
+    def setup_method(self):
         from lenstronomy.LensModel.Profiles.spemd import SPEMD
         self.SPEMD = SPEMD(suppress_fastell=True)
         from lenstronomy.LensModel.Profiles.nie import NIE
