@@ -13,7 +13,7 @@ class TestLensModel(object):
     """
     tests the source model routines
     """
-    def setup(self):
+    def setup_method(self):
         self.lensModel = LensModel(['GAUSSIAN'])
         self.kwargs = [{'amp': 1., 'sigma_x': 2., 'sigma_y': 2., 'center_x': 0., 'center_y': 0.}]
 
