@@ -10,7 +10,7 @@ class TestInterpol(object):
     """
     class to test Shapelets
     """
-    def setup(self):
+    def setup_method(self):
         pass
 
     def test_function(self):
