@@ -7,7 +7,7 @@ class TestMoffat(object):
     """
     class to test the Moffat profile
     """
-    def setup(self):
+    def setup_method(self):
         pass
 
     def test_function(self):
