@@ -10,7 +10,7 @@ class TestNumerics(object):
     """
     tests the second derivatives of various lens models
     """
-    def setup(self):
+    def setup_method(self):
         pass
 
     def assert_integrals(self, Model, kwargs):
