@@ -7,7 +7,7 @@ from lenstronomy.LensModel.lens_model import LensModel
 
 class TestPSBase(object):
 
-    def setup(self):
+    def setup_method(self):
         self.base = PSBase(lens_model=LensModel(lens_model_list=[]), fixed_magnification=False, additional_image=False)
         PSBase(fixed_magnification=True, additional_image=True)
 
@@ -23,7 +23,7 @@ class TestPSBase(object):
 
 class TestUtil(object):
 
-    def setup(self):
+    def setup_method(self):
         pass
 
     def test_expand_to_array(self):
