@@ -44,7 +44,7 @@ class TestMultiNestSampler(object):
     test the fitting sequences
     """
 
-    def setup(self):
+    def setup_method(self):
 
         pass
 
